@@ -124,7 +124,6 @@ func NewConfluentCommand(cfg *v1.Config) *cobra.Command {
 	cmd.AddCommand(schemaregistry.New(cfg, prerunner, nil))
 	cmd.AddCommand(secret.New(prerunner, flagResolver, secrets.NewPasswordProtectionPlugin()))
 	cmd.AddCommand(shell.New(cmd, func() *cobra.Command { return NewConfluentCommand(cfg) }))
-	cmd.AddCommand(update.New(prerunner, cfg.Version, updateClient))
 	cmd.AddCommand(version.New(prerunner, cfg.Version))
 
 	dc := dynamicconfig.New(cfg, nil, nil)
@@ -133,6 +132,10 @@ func NewConfluentCommand(cfg *v1.Config) *cobra.Command {
 		cmd.AddCommand(streamshare.New(cfg, prerunner))
 	}
 
+	if !cfg.DisableUpdates {
+		cmd.AddCommand(update.New(cfg, prerunner, updateClient))
+	}
+
 	changeDefaults(cmd, cfg)
 	deprecateCommandsAndFlags(cmd, cfg)
 	return cmd
