@@ -6,6 +6,7 @@ import (
 	"os"
 	"path/filepath"
 	"reflect"
+	"regexp"
 	"strings"
 
 	"github.com/google/uuid"
@@ -62,10 +63,6 @@ var (
 		"you must log in to Confluent Platform to use this command",
 		"Log in with `confluent login --url <mds-url>`.",
 	)
-	RequireUpdatesEnabledErr = errors.NewErrorWithSuggestions(
-		"you must enable updates to use this command",
-		"WARNING: To guarantee compatibility, enabling updates is not recommended for Confluent Platform users.\n"+`In ~/.confluent/config.json, set "disable_updates": false`,
-	)
 )
 
 // Config represents the CLI configuration.
@@ -73,7 +70,7 @@ type Config struct {
 	*config.BaseConfig
 
 	DisableUpdateCheck  bool                        `json:"disable_update_check"`
-	DisableUpdates      bool                        `json:"disable_updates"`
+	DisableUpdates      bool                        `json:"disable_updates,omitempty"`
 	DisablePlugins      bool                        `json:"disable_plugins"`
 	DisablePluginsOnce  bool                        `json:"disable_plugins_once,omitempty"`
 	DisableFeatureFlags bool                        `json:"disable_feature_flags"`
@@ -133,6 +130,24 @@ func New() *Config {
 	}
 }
 
+func (c *Config) DecryptContextStates() error {
+	if context := c.Context(); context != nil {
+		state := c.ContextStates[context.Name]
+		if state != nil {
+			err := state.DecryptContextStateAuthToken(context.Name)
+			if err != nil {
+				return err
+			}
+			err = state.DecryptContextStateAuthRefreshToken(context.Name)
+			if err != nil {
+				return err
+			}
+		}
+		context.State = state
+	}
+	return c.Validate()
+}
+
 // Load reads the CLI config from disk.
 // Save a default version if none exists yet.
 func (c *Config) Load() error {
@@ -184,19 +199,7 @@ func (c *Config) Load() error {
 			return errors.NewCorruptedConfigError(errors.MissingKafkaClusterContextErrorMsg, context.Name, c.Filename)
 		}
 		context.KafkaClusterContext.Context = context
-
-		state := c.ContextStates[context.Name]
-		if state != nil {
-			err = state.DecryptContextStateAuthToken(context.Name)
-			if err != nil {
-				return err
-			}
-			err = state.DecryptContextStateAuthRefreshToken(context.Name)
-			if err != nil {
-				return err
-			}
-		}
-		context.State = state
+		context.State = c.ContextStates[context.Name]
 	}
 	return c.Validate()
 }
@@ -259,14 +262,16 @@ func (c *Config) encryptContextStateTokens(tempAuthToken, tempAuthRefreshToken s
 		c.Context().GetState().Salt = salt
 		c.Context().GetState().Nonce = nonce
 	}
-	if tempAuthToken != "" {
+
+	if regexp.MustCompile(authTokenRegex).MatchString(tempAuthToken) {
 		encryptedAuthToken, err := secret.Encrypt(c.Context().Name, tempAuthToken, c.Context().GetState().Salt, c.Context().GetState().Nonce)
 		if err != nil {
 			return err
 		}
 		c.Context().GetState().AuthToken = encryptedAuthToken
 	}
-	if tempAuthRefreshToken != "" {
+
+	if regexp.MustCompile(authRefreshTokenRegex).MatchString(tempAuthRefreshToken) {
 		encryptedAuthRefreshToken, err := secret.Encrypt(c.Context().Name, tempAuthRefreshToken, c.Context().GetState().Salt, c.Context().GetState().Nonce)
 		if err != nil {
 			return err
@@ -670,13 +675,6 @@ func (c *Config) CheckIsNonCloudLogin() error {
 	return nil
 }
 
-func (c *Config) CheckAreUpdatesEnabled() error {
-	if c.DisableUpdates {
-		return RequireUpdatesEnabledErr
-	}
-	return nil
-}
-
 func (c *Config) IsCloudLogin() bool {
 	return c.CheckIsCloudLogin() == nil
 }
